pub trait FnSubscriptionBody<Args>{
type Output: Stream<Item = Args::Item> + Send;
// Required method
fn run(
&self,
updates: impl Stream<Item = Args::Update> + Send + 'static,
args: Args,
) -> (Args::InitialReply, Self::Output);
}Expand description
An implementation of a subscription service.
You shouldn’t need to implement this, as a blanket implementation is
provided for any async function or closure that takes a single
FnSubscription argument and returns a stream of
FnSubscription::Item.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.