pub trait FnRemoteBody<Args>where
    Args: FnRemote,
{ type Fut: Future<Output = Args::Output> + Send + Sync; fn run(&self, args: Args) -> Self::Fut; }
An implementation of a remote function.

You shouldn’t need to implement this, as a blanket implementation is provided for any async function or closure that takes a single FnRemote argument and returns the FnRemote::Output. The future must be Send + Sync.

Required Associated Types

source

type Fut: Future<Output = Args::Output> + Send + Sync

Required Methods

source

fn run(&self, args: Args) -> Self::Fut

Evaluate the function.

Implementors

source

impl<Args, Fut, F> FnRemoteBody<Args> for Fwhere
    Args: FnRemote,
    F: Fn(Args) -> Fut,
    Fut: Future<Output = Args::Output> + Send + Sync,



type Fut = Fut