Trait arpy_server::FnRemoteBody
source · pub trait FnRemoteBody<Args>where
Args: FnRemote,{
type Fut: Future<Output = Args::Output> + Send + Sync;
fn run(&self, args: Args) -> Self::Fut;
}Expand description
An implementation of a remote function.
You shouldn’t need to implement this, as a blanket implementation is
provided for any async function or closure that takes a single
FnRemote argument and returns the FnRemote::Output. The future must
be Send + Sync.